@@ -1,27 +1,25 @@
 import os
 import re
 
-from prospector.formatters.base import Formatter
+from prospector.formatters.base_summary import SummaryFormatter
 
 
-class VSCodeFormatter(Formatter):
-
+class VSCodeFormatter(SummaryFormatter):
     """
     This formatter outputs messages in the same way as vscode prospector linter expects.
     """
 
-    def render(self, summary=True, messages=True, profile=False):
-        # this formatter will always ignore the summary and profile
+    def render_messages(self) -> list[str]:
         cur_loc = None
         output = []
 
         for message in sorted(self.messages):
             if cur_loc != message.location.path:
                 cur_loc = message.location.path
-                module_name = self._make_path(message.location.path).replace(os.path.sep, ".")
+                module_name = str(self._make_path(message.location)).replace(os.path.sep, ".")
                 module_name = re.sub(r"(\.__init__)?\.py$", "", module_name)
 
-                header = "************* Module %s" % module_name
+                header = f"************* Module {module_name}"
                 output.append(header)
 
             template = "%(line)s,%(character)s,%(code)s,%(code)s:%(source)s %(message)s"
@@ -35,5 +33,17 @@ class VSCodeFormatter(Formatter):
                     "message": message.message.strip(),
                 }
             )
+        return output
+
+    def render(self, summary: bool = True, messages: bool = True, profile: bool = False) -> str:
+        output: list[str] = []
+        if messages:
+            output.extend(self.render_messages())
+        if profile:
+            output.append("")
+            output.append(self.render_profile())
+        if summary:
+            output.append("")
+            output.append(self.render_summary())
 
         return "\n".join(output)
