@@ -1,8 +1,8 @@
 from io import StringIO
-from typing import List
 
 from pylint.exceptions import UnknownMessageError
 from pylint.message import Message as PylintMessage
+from pylint.message import MessageDefinitionStore
 from pylint.reporters import BaseReporter
 
 from prospector.message import Location, Message
@@ -11,13 +11,13 @@ from prospector.message import Location, Message
 class Collector(BaseReporter):
     name = "collector"
 
-    def __init__(self, message_store):
+    def __init__(self, message_store: MessageDefinitionStore) -> None:
         BaseReporter.__init__(self, output=StringIO())
         self._message_store = message_store
-        self._messages = []
+        self._messages: list[Message] = []
 
     def handle_message(self, msg: PylintMessage) -> None:
-        loc = Location(msg.abspath, msg.module, msg.obj, msg.line, msg.column)
+        loc = Location(msg.abspath, msg.module, msg.obj, msg.line, msg.column, msg.end_line, msg.end_column)
 
         # At this point pylint will give us the code but we want the
         # more user-friendly symbol
@@ -31,11 +31,14 @@ class Collector(BaseReporter):
         else:
             msg_symbol = msg_data[0].symbol
 
-        message = Message("pylint", msg_symbol, loc, msg.msg)
+        message = Message(
+            "pylint",
+            msg_symbol,
+            loc,
+            msg.msg,
+            doc_url=f"https://pylint.readthedocs.io/en/latest/user_guide/messages/{msg.category}/{msg.symbol}.html",
+        )
         self._messages.append(message)
 
-    def _display(self, layout) -> None:
-        pass
-
-    def get_messages(self) -> List[Message]:
+    def get_messages(self) -> list[Message]:
         return self._messages
